from setuptools import setup, find_packages

setup(
    name="langs-vall", 
    version="0.0.4",
    author="Breyston Gonzalez",
    author_email="<breystonbarton15@gmail.com>",
    description="Paquete de vall-e-x para proyecto de traduccion de lenguajes",
    long_description="",
    packages=find_packages("/vall-dependency"),
    keywords=['python', 'vall-e-x']
)
